pub struct Ed25519Verifier { /* private fields */ }Expand description
Verifies plugin signatures against a fixed set of trusted public keys. 用一组固定可信公钥验证插件签名。
Implementations
Sourceimpl Ed25519Verifier
impl Ed25519Verifier
Sourcepub const fn new(keys: &'static [TrustedPublicKey]) -> Self
pub const fn new(keys: &'static [TrustedPublicKey]) -> Self
Trust exactly the listed keys for the lifetime of the verifier. 在验证器生命周期内只信任列出的公钥。